==> ripe-dbase-3.0.0.tar.gz: ripe-dbase-3.0/modules/up/dbupdate.h <==
#ifndef UPDATE_UPPER_H
#define UPDATE_UPPER_H


#include <stdio.h>
#include <stdlib.h> 
#include <string.h> 
#include <stubs.h>
#include <string>
#include <glib.h>
#include <iostream.h>
#include <fstream>

#include <netdb.h> 
#include <sys/types.h> 
#include <netinet/in.h> 
#include <sys/socket.h> 
#include <errno.h> 
#include <unistd.h>

#include <config.h>
#include <istream.h>
#include "rpsl/object.hh"
#include "util/rusage.hh"
#include "util/debug.hh"
#include "util/trace.hh"
#include "util/Argv.hh"
#include "util/version.hh"
#ifdef IRR_NEEDED
#include "irr/irr.hh"
#include "irr/rawhoisc.hh"
#endif // IRR_NEEDED
#include "rpsl/schema.hh"
#include "erroutines.h"
#include "AU_util.h"
#include "ack.h"
#define private private_xx
#include "mm.h"
#include "mysql_driver.h"
//#include "mail_parser.h"
#undef private


#define MAXDATASIZE 100 /* max number of bytes we can get at once */

#define OVR_OK 0 /* override succeded */


//#define UPDATE_SOURCE "RIPE"

#define ACK_FILE_PREFIX "ack"

typedef enum {
  UP_AUTH_OK=0, /* Auth succeded */
  UP_MOR, /* got more than one object from the db, where extected only one */
  UP_NSO, /* no such object */
  UP_AUF, /* auth failed */
  UP_NIY, /* not implemented yet */
  UP_ABN, /* as-block does not exist */
  UP_HOF, /* hierarchical auth failed */
  UP_OVF, /* override failed */
  UP_OVS, /* override syntax error */
  UP_NOM, /* no match. the old & nw versions of the object are not the same */
  UP_ANE, /* AUTO NIC hdl error */
  UP_FWD, /* mntner or as-block creation will be forwarded to <HUMAILBOX> */
  UP_INT  /* internal error */

} return_codes;


#ifdef __cplusplus
extern "C" {
#endif



int send_object_db(char * arg, char * assigned_NIC, char * operation);

char * get_class_type(Object *arg);

char * get_search_key(Object *arg, char * type, const char * text);

GSList *get_attributes(Object * o, const char * attrib, const char * text);

char * send_and_get(char * host, int port, char * arg);

int count_objects(char * arg);

char * take_object(char * arg);

char * get_as_block(char *autnum_object);

char * get_less_specific_domain(char *domain_object);

char * get_less_specific_set(char *set_object, char *type);

char * get_less_specific(char *inetnum_object, char *type);

GSList *get_mntners(char * object);

GSList *get_auths(char * object);

GSList *get_attr_list(char * object, char * attr_type);

GSList *get_mnt_lowers(char * object);

char *get_override(char * object);

int check_override(char * string);

GSList * add_to_auth_vector(GSList * list_of_auth_struct, GSList * auths, char * mntner_name);

GSList * get_auth_vector(GSList * mntners);

GSList * get_mntnfy_vector(GSList * mntners);

int check_auth(char *new_object, char *old_object, char *type, credentials_struct credentials);

char * get_old_version(char * arg);

//int process_object(char * arg, credentials_struct credentials, GHashTable * NIC_hdl_hash, char * ack_file_name);

void process_mail_header(credentials_struct * credentials_ptr ,char * header);

int has_ref_to_AUTO_nic_hdl(const char * object);

char * find_email_address(const char * from_line);

char * replace_refs_to_AUTO_NIC_hdl(char * changed_obj, char * arg, GHashTable * auto_nic_hash);

int identical(const char * old_version, const char * new_version);

int has_AUTO_NIC_hdl(const char * object);

char * replace_AUTO_NIC_hdl(char * arg, char * auto_nic_hdl);

char * get_class_type_char(char * object);

void up_string_pack(char *dest, const char *source);

#ifdef __cplusplus
}
#endif


#endif

==> ripe-dbase-3.0.1.tar.gz: ripe-dbase-3.0.1/modules/up/dbupdate.h <==
#ifndef UPDATE_UPPER_H
#define UPDATE_UPPER_H


#include <stdio.h>
#include <stdlib.h> 
#include <string.h> 
#include <stubs.h>
#include <string>
#include <glib.h>
#include <iostream.h>
#include <fstream>

#include <netdb.h> 
#include <sys/types.h> 
#include <netinet/in.h> 
#include <sys/socket.h> 
#include <errno.h> 
#include <unistd.h>

#include <config.h>
#include <istream.h>
#include "rpsl/object.hh"
#include "util/rusage.hh"
#include "util/debug.hh"
#include "util/trace.hh"
#include "util/Argv.hh"
#include "util/version.hh"
#ifdef IRR_NEEDED
#include "irr/irr.hh"
#include "irr/rawhoisc.hh"
#endif // IRR_NEEDED
#include "rpsl/schema.hh"
#include "erroutines.h"
#include "AU_util.h"
#include "ack.h"
#define private private_xx
#include "mm.h"
#include "mysql_driver.h"
//#include "mail_parser.h"
#undef private


#define MAXDATASIZE 100 /* max number of bytes we can get at once */

#define OVR_OK 0 /* override succeded */


#define ACK_FILE_PREFIX "ack"

typedef enum {
  UP_AUTH_OK=0, /* Auth succeded */
  UP_MOR, /* got more than one object from the db, where extected only one */
  UP_NSO, /* no such object */
  UP_AUF, /* auth failed */
  UP_NIY, /* not implemented yet */
  UP_ABN, /* as-block does not exist */
  UP_HOF, /* hierarchical auth failed */
  UP_OVF, /* override failed */
  UP_OVS, /* override syntax error */
  UP_NOM, /* no match. the old & nw versions of the object are not the same */
  UP_ANE, /* AUTO NIC hdl error */
  UP_FWD, /* mntner or as-block creation will be forwarded to <HUMAILBOX> */
  UP_SYN, /* syntax error in the object */
  UP_INT  /* internal error */

} return_codes;

typedef struct _up_ripupd_result_struct {
  int result;
  char * error_str;
} up_ripupd_result_struct;


#ifdef __cplusplus
extern "C" {
#endif



up_ripupd_result_struct * send_object_db(char * arg, char * assigned_NIC, char * operation);

char * get_class_type(Object *arg);

char * get_search_key(Object *arg, char * type, const char * text);

GSList *get_attributes(Object * o, const char * attrib, const char * text);

char * send_and_get(char * host, int port, char * arg);

int count_objects(char * arg);

char * take_object(char * arg);

char * get_as_block(char *autnum_object);

char * get_less_specific_domain(char *domain_object);

char * get_less_specific_set(char *set_object, char *type);

char * get_less_specific(char *inetnum_object, char *type);

GSList *get_mntners(char * object);

GSList *get_auths(char * object);

GSList *get_attr_list(char * object, char * attr_type);

GSList *get_mnt_lowers(char * object);

char *get_override(char * object);

int check_override(char * string);

GSList * add_to_auth_vector(GSList * list_of_auth_struct, GSList * auths, char * mntner_name);

GSList * get_auth_vector(GSList * mntners);

GSList * get_mntnfy_vector(GSList * mntners);

int check_auth(char *new_object, char *old_object, char *type, credentials_struct credentials);

char * get_old_version(char * arg);

//int process_object(char * arg, credentials_struct credentials, GHashTable * NIC_hdl_hash, char * ack_file_name);

void process_mail_header(credentials_struct * credentials_ptr ,char * header);

int has_ref_to_AUTO_nic_hdl(const char * object);

char * find_email_address(const char * from_line);

char * replace_refs_to_AUTO_NIC_hdl(char * changed_obj, char * arg, GHashTable * auto_nic_hash);

int identical(const char * old_version, const char * new_version);

int has_AUTO_NIC_hdl(const char * object);

char * replace_AUTO_NIC_hdl(char * arg, char * auto_nic_hdl);

char * get_class_type_char(char * object);

void up_string_pack(char *dest, const char *source);

void UP_add_to_upd_log(const char * filename); 

void UP_log_networkupdate(const char * object, const char * host);

#ifdef __cplusplus
}
#endif


#endif
